==> open-xchange-core_7.2.2.orig.tar.bz2: open-xchange-core-7.2.2/com.openexchange.server/src/com/openexchange/database/provider/DBProvider.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.database.provider;

import java.sql.Connection;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.contexts.Context;

public interface DBProvider {

    static final DBProvider DUMMY = new DBProvider() {
        @Override
        public Connection getReadConnection(final Context ctx) {
            throw new UnsupportedOperationException();
        }
        @Override
        public Connection getWriteConnection(final Context ctx) {
            throw new UnsupportedOperationException();
        }
        @Override
        public void releaseReadConnection(final Context ctx, final Connection con) {
            throw new UnsupportedOperationException();
        }
        @Override
        public void releaseWriteConnection(final Context ctx, final Connection con) {
            throw new UnsupportedOperationException();
        }
    };

    Connection getReadConnection(Context ctx) throws OXException;

    void releaseReadConnection(Context ctx, Connection con);

    Connection getWriteConnection(Context ctx) throws OXException;

    void releaseWriteConnection(Context ctx, Connection con);
}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.server/src/com/openexchange/database/provider/DBProvider.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.database.provider;

import java.sql.Connection;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.contexts.Context;

/**
 * {@link DBProvider} - Provides connections for database access.
 *
 * @author <a href="mailto:info@open-xchange.com">Open-Xchange Engineering</a>
 */
public interface DBProvider {

    /**
     * The dummy provider.
     */
    static final DBProvider DUMMY = new DBProvider() {
        @Override
        public Connection getReadConnection(final Context ctx) {
            throw new UnsupportedOperationException();
        }
        @Override
        public Connection getWriteConnection(final Context ctx) {
            throw new UnsupportedOperationException();
        }
        @Override
        public void releaseReadConnection(final Context ctx, final Connection con) {
            throw new UnsupportedOperationException();
        }
        @Override
        public void releaseWriteConnection(final Context ctx, final Connection con) {
            throw new UnsupportedOperationException();
        }
        @Override
        public void releaseWriteConnectionAfterReading(Context ctx, Connection con) {
            throw new UnsupportedOperationException();
        }
    };

    /**
     * Gets a read-only connection for <code>SELECT</code> statements.
     *
     * @param ctx The associated context
     * @return A read-only connection
     * @throws OXException If connection cannot be returned
     */
    Connection getReadConnection(Context ctx) throws OXException;

    /**
     * Releases specified read-only connection.
     *
     * @param ctx The associated context
     * @param con The connection to release
     */
    void releaseReadConnection(Context ctx, Connection con);

    /**
     * Gets a read-write connection for <code>INSERT</code>, <code>UPDATE</code>, and/or <code>DELETE</code> statements.
     *
     * @param ctx The associated context
     * @return A read-write connection
     * @throws OXException If connection cannot be returned
     */
    Connection getWriteConnection(Context ctx) throws OXException;

    /**
     * Releases specified read-write connection.
     *
     * @param ctx The associated context
     * @param con The connection to release
     */
    void releaseWriteConnection(Context ctx, Connection con);

    /**
     * Releases specified read-write connection that was <b>only</b> used for read accesses.
     *
     * @param ctx The associated context
     * @param con The connection to release
     */
    void releaseWriteConnectionAfterReading(Context ctx, Connection con);

}
